<?php

namespace Drupal\index_now\Service;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Key generator service.
 */
final class IndexNowKeyManager implements IndexNowKeyManagerInterface {

  /**
   * The Index Now config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The Uuid service.
   *
   * @var \Drupal\Component\Uuid\UuidInterface
   */
  protected $uuid;

  /**
   * Key Generator constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Component\Uuid\UuidInterface $uuid
   *   The uuid service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    UuidInterface $uuid
  ) {
    $this->config = $config_factory->getEditable('index_now.settings');
    $this->uuid = $uuid;
  }

  /**
   * {@inheritdoc}
   */
  public function generateKey(): void {
    // Generate a random API key.
    $api_key = $this->uuid->generate();

    // Store the API key.
    $this->config->set('api_key', $api_key)
      ->save();
  }

  /**
   * {@inheritdoc}
   */
  public function getKey() : string {
    return $this->config->get('api_key') ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() : array {
    return [
      'config:index_now.settings',
    ];
  }

}
